package com.example.cristina.tipcalculatorandroid;

import android.content.Intent;
import android.provider.Settings;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.SeekBar;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.SeekBar.OnSeekBarChangeListener;


public class MainActivity extends AppCompatActivity {

    //1. After you drag and drop your labels and other views in the .xml file (your viewer), you hsould declare your variables here!
    //If some of the variables are highlighted in red, it means that you should import them. (alt+Enter)
    TipCalculatorModel tipCalc;
    TextView billLabel;
    TextView tipLabel;
    SeekBar tipSlider;
    EditText billNumber;


    //Constant strings needed to send/pack the extra information in the intent.
    public final static String EXTRA_MESSAGE = "com.example.tipcalculatorandroid.MESSAGE";
    public final static String TIP_MESSAGE = "com.example.tipcalculatorandroid.TIP";


    //1.1 The onCreate method gets called the first time you initialize a view.
    // However if you add event listeners inside it, they will be called everytime the event gets triggered.
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_main);

        //2. initialize view variables in the UI (function definition is below onCreate())
        initializeVariables();

        //2.2 Set initial value for the labels.
        tipLabel.setText("Tip Percentage: (" + tipSlider.getProgress() + "%)" );
        billNumber.setText("100");

        double tipPercentage = tipSlider.getProgress()/100;

        //System.out.println("Input: "+ billNumber.getText());

        //2.2 Initialize your model Variables. If you have multiple models, consider implementing another init function.
        tipCalc = new TipCalculatorModel(Integer.parseInt(billNumber.getText().toString()), tipPercentage);

        //3. Event Listener for the the Seekbar slider. It gets called everytime a user interacts with the slider.
        tipSlider.setOnSeekBarChangeListener(new OnSeekBarChangeListener() {
            int progress = 0;

            //3.1 This function gets called every time the progress on the bar gets changed.
            @Override
            public void onProgressChanged(SeekBar seekBar, int progresValue, boolean fromUser) {
                progress = progresValue;
                tipLabel.setText("Tip Percentage: (" + progress + "%)" );
                tipCalc.setTip((double)progress/100);

                Toast.makeText(getApplicationContext(), "Changing seekbar's progress", Toast.LENGTH_SHORT).show();
            }

            //3.2 This function gets called every time the user starts interacting with the slider
            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {
            }

            //3.3 This function gets called every time the user stops interacting with the slider
            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {

            }

        });

    }

    //2.1 The initilization function for the views controlled by your activity
    private void initializeVariables() {
        billLabel = (TextView) findViewById(R.id.billLabel);
        tipLabel = (TextView) findViewById(R.id.tipLabel);
        tipSlider = (SeekBar) findViewById(R.id.tipSlider);
        billNumber = (EditText) findViewById(R.id.billNumber);
    }

    //4. This function gets called everytime you tapped the button.
    // The name of the function has to be the same name you set in the .xml file, in the button section
    // e.G.: android:onClick="calculateTapped"
    public void calculateTapped(View view) {
        // Do something in response to button

        //5. In our case when we tap the calculate button, we want to transition to a new view.
        // The intent is an object where we pack the event we want to trigger. What we want is to assign the intent
        // the new activity (SuccessActivity).
        Intent intent = new Intent(this, SuccessActivity.class);
        tipCalc.setBill(Integer.parseInt(billNumber.getText().toString()));
        //System.out.println("TipCalc: " + tipCalc.getBill() + " " + tipCalc.getTip() + " " + tipCalc.getTotal());

        //5.1 Additionally, we also pack information that this view contains/knows, but the new view does not.
        // In the following line we want to send the tip we selected and the total amount to pay to the next view.
        intent.putExtra(EXTRA_MESSAGE, String.valueOf(tipCalc.getTotal()));
        intent.putExtra(TIP_MESSAGE, String.valueOf(tipCalc.getTip()));

        //5.2 After packing everything inside the intent, we can start the new activity.
        startActivity(intent);

    }
}
